@@ -1,5 +1,5 @@
 package HTML::MagicTemplate          ;
-$VERSION = 3.1                       ;
+$VERSION = 3.11                      ;
 use strict                           ;
 use Text::MagicTemplate              ;
 push our @ISA, 'Text::MagicTemplate' ;
@@ -81,7 +81,7 @@ sub FillInForm # value handler
 
 HTML::MagicTemplate - HTML handlers for Text::MagicTemplate used in a HTML environment.
 
-=head1 VERSION 3.1
+=head1 VERSION 3.11
 
 =head1 SYNOPSIS
 
@@ -354,9 +354,6 @@ More information at http://perl.4pro.net/?HTML::MagicTemplate.
 
 Domizio Demichelis, <dd@4pro.net>.
 
-=for html
-<img src="http://perl.4pro.net/bug?HTML::MagicTemplate" height="1" width="1" border="0">
-
 =head1 COPYRIGHT
 
 Copyright (c)2002 Domizio Demichelis. All Rights Reserved. This is free software; it may be used freely and redistributed for free providing this copyright header remains part of the software. You may not charge for the redistribution of this software. Selling this code without Domizio Demichelis' written permission is expressly forbidden.
